@@ -17,7 +17,7 @@ use strict;
 use warnings;
 use FileHandle;
 
-our $VERSION = '1.15';
+our $VERSION = '1.16';
 our $DEBUG   = 0;
 
 sub new
@@ -242,7 +242,8 @@ sub UnLZW
 			$codesize++;
 		}
 	}
-	$result .= $table[$c1];
+
+	$result .= $table[$c1] if defined $table[$c1];
 
 	$result;
 }
